/**
 * GNU Public License (GPL).
 *
 * This software is published under the terms of the GNU Public License (GPL),
 * a copy of which is included in this distribution.
 */

package org.jivesoftware.openfire.plugin;

import org.jivesoftware.openfire.container.Plugin;
import org.jivesoftware.openfire.container.PluginManager;
import org.jivesoftware.openfire.interceptor.PacketInterceptor;
import org.jivesoftware.openfire.interceptor.PacketRejectedException;
import org.jivesoftware.openfire.interceptor.InterceptorManager;
import org.jivesoftware.openfire.session.Session;
import org.jivesoftware.util.JiveGlobals;
import org.jivesoftware.util.Log;
import org.jivesoftware.util.StringUtils;
import org.xmpp.packet.*;
import java.io.File;

public class Dropper implements Plugin, PacketInterceptor {
	private InterceptorManager interceptorManager;
	private boolean logEnabled = DEFAULT_PROPERTY_LOG_ENABLED;
	private String version;

	/** = {@value} */
	private static final String PROPERTY_LOG_ENABLED = "plugin.dropper.log";
	/** = {@value} */
	private static final boolean DEFAULT_PROPERTY_LOG_ENABLED = true;


	public void initializePlugin(PluginManager manager, File pluginDirectory) {	
		interceptorManager = InterceptorManager.getInstance();		
		interceptorManager.addInterceptor(this);

		logEnabled = JiveGlobals.getBooleanProperty(PROPERTY_LOG_ENABLED, DEFAULT_PROPERTY_LOG_ENABLED);

		version = manager.getVersion(this);
		
		Log.info("Dropper : starting version '" + version + "'.");
	}		

	public void destroyPlugin() {
		interceptorManager.removeInterceptor(this);
		Log.info("Dropper : stoping version '" + version + "'.");
	}

	public void interceptPacket(Packet packet, Session session, boolean incoming, boolean processed)
			throws PacketRejectedException {
		// check for unprocessed IQ packets without ID attribute
		if (processed || !(packet instanceof IQ)) { return; }
		IQ iq = (IQ)packet;
		if (iq.getID() != null) { return; }

		// add random ID attribute
		String rnd = StringUtils.randomString(12).toLowerCase();
		iq.setID(rnd);

		if (logEnabled) {
			// get fromJID
			JID from = iq.getFrom();
			if (from == null) {
				from = session.getAddress();
			}

			// log message		
			Log.info("Dropper: found and repaired illegal IQ packet from '" + from.toString() + "'");
		}
	}
}
